@@ -37,6 +37,9 @@ from .fetchers import NUGatewaySecuritiesFetcher
 from .fetchers import NUPATNATPoolsFetcher
 
 
+from .fetchers import NUDdnsconfigsFetcher
+
+
 from .fetchers import NUPermissionsFetcher
 
 
@@ -118,7 +121,7 @@ class NUNSGateway(NURESTObject):
     """ Represents a NSGateway in the VSD
 
         Notes:
-            Network Services Gateways are a policy enforcement end-points responsible for the delivery of networking services. NSG access ports/VLANs may be attached to existing host or bridge VPorts.
+            Network Services Gateways are a policy enforcement end-points responsible for the delivery of networking services. NSG access ports/VLANs may be attached to existing host or bridge vPorts.
     """
 
     __rest_name__ = "nsgateway"
@@ -139,7 +142,7 @@ class NUNSGateway(NURESTObject):
     
     CONST_CONFIGURATION_RELOAD_STATE_FAILED_TO_APPLY = "FAILED_TO_APPLY"
     
-    CONST_FUNCTIONS_HUB = "HUB"
+    CONST_NETWORK_ACCELERATION_WIFI_OPTIMIZED = "WIFI_OPTIMIZED"
     
     CONST_BOOTSTRAP_STATUS_REVOKED = "REVOKED"
     
@@ -245,12 +248,18 @@ class NUNSGateway(NURESTObject):
     
     CONST_NETWORK_ACCELERATION_TP_AWARE = "TP_AWARE"
     
+    CONST_NETWORK_ACCELERATION_WIFI_VNF_AWARE = "WIFI_VNF_AWARE"
+    
     CONST_ZFB_MATCH_ATTRIBUTE_SERIAL_NUMBER = "SERIAL_NUMBER"
     
+    CONST_FUNCTIONS_HUB = "HUB"
+    
     CONST_NETWORK_ACCELERATION_SESSION_OPTIMIZED = "SESSION_OPTIMIZED"
     
     CONST_ZFB_MATCH_ATTRIBUTE_UUID = "UUID"
     
+    CONST_NETWORK_ACCELERATION_WIFI_TP_AWARE = "WIFI_TP_AWARE"
+    
     CONST_FAMILY_NSG_AMI = "NSG_AMI"
     
     CONST_PERMITTED_ACTION_DEPLOY = "DEPLOY"
@@ -308,6 +317,7 @@ class NUNSGateway(NURESTObject):
         self._tcp_maximum_segment_size = None
         self._zfb_match_attribute = None
         self._zfb_match_value = None
+        self._sgt_propagation_enabled = None
         self._bios_release_date = None
         self._bios_version = None
         self._sku = None
@@ -379,6 +389,7 @@ class NUNSGateway(NURESTObject):
         self.expose_attribute(local_name="tcp_maximum_segment_size", remote_name="TCPMaximumSegmentSize", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="zfb_match_attribute", remote_name="ZFBMatchAttribute", attribute_type=str, is_required=False, is_unique=False, choices=[u'HOSTNAME', u'IP_ADDRESS', u'MAC_ADDRESS', u'NONE', u'NSGATEWAY_ID', u'SERIAL_NUMBER', u'UUID'])
         self.expose_attribute(local_name="zfb_match_value", remote_name="ZFBMatchValue", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="sgt_propagation_enabled", remote_name="SGTPropagationEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="bios_release_date", remote_name="BIOSReleaseDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="bios_version", remote_name="BIOSVersion", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="sku", remote_name="SKU", attribute_type=str, is_required=False, is_unique=False)
@@ -408,7 +419,7 @@ class NUNSGateway(NURESTObject):
         self.expose_attribute(local_name="personality", remote_name="personality", attribute_type=str, is_required=False, is_unique=False, choices=[u'NSG', u'NSGBR', u'NSGDUC'])
         self.expose_attribute(local_name="cert_validity_days", remote_name="certValidityDays", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="network_acceleration", remote_name="networkAcceleration", attribute_type=str, is_required=False, is_unique=False, choices=[u'NONE', u'PERFORMANCE', u'SESSION_OPTIMIZED', u'TP_AWARE', u'VNF_AWARE'])
+        self.expose_attribute(local_name="network_acceleration", remote_name="networkAcceleration", attribute_type=str, is_required=False, is_unique=False, choices=[u'NONE', u'PERFORMANCE', u'SESSION_OPTIMIZED', u'TP_AWARE', u'VNF_AWARE', u'WIFI_OPTIMIZED', u'WIFI_TP_AWARE', u'WIFI_VNF_AWARE'])
         self.expose_attribute(local_name="threat_prevention_enabled", remote_name="threatPreventionEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="libraries", remote_name="libraries", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
@@ -455,6 +466,9 @@ class NUNSGateway(NURESTObject):
         self.patnat_pools = NUPATNATPoolsFetcher.fetcher_with_object(parent_object=self, relationship="member")
         
         
+        self.ddnsconfigs = NUDdnsconfigsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.permissions = NUPermissionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -750,6 +764,33 @@ class NUNSGateway(NURESTObject):
         self._zfb_match_value = value
 
     
+    @property
+    def sgt_propagation_enabled(self):
+        """ Get sgt_propagation_enabled value.
+
+            Notes:
+                Indicates if Security Group Tag Propagation is enabled on Network Accelerated NSG and Network Accelerated UBR with HUB or HUB and DUC function(s).
+
+                
+                This attribute is named `SGTPropagationEnabled` in VSD API.
+                
+        """
+        return self._sgt_propagation_enabled
+
+    @sgt_propagation_enabled.setter
+    def sgt_propagation_enabled(self, value):
+        """ Set sgt_propagation_enabled value.
+
+            Notes:
+                Indicates if Security Group Tag Propagation is enabled on Network Accelerated NSG and Network Accelerated UBR with HUB or HUB and DUC function(s).
+
+                
+                This attribute is named `SGTPropagationEnabled` in VSD API.
+                
+        """
+        self._sgt_propagation_enabled = value
+
+    
     @property
     def bios_release_date(self):
         """ Get bios_release_date value.
